@@ -15,7 +15,7 @@
 # Create a modules subdirectory in your data directory, and put the
 # file in there. It will be loaded automatically.
 #
-$ModulesDescription .= '<p>$Id: romanian-utf8.pl,v 1.5 2006/05/10 22:52:16 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: romanian-utf8.pl,v 1.6 2006/05/16 19:08:48 victor_os Exp $</p>';
 %Translate = split(/\n/,<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 Citirea nu este permisă: utilizatorul, ip-ul sau reţeaua este blocată.
@@ -36,9 +36,9 @@ diferenţe
 history
 istoric
 %s returned no data, or LWP::UserAgent is not available.
-
+%s nu a returnat date, sau LWP::UserAgent nu este disponibil.
 RSS parsing failed for %s
-
+Nu a reuşit parcurgerea RSS pentru %s
 No items found in %s.
 Nici un element găsit în %s.
  . . . . 
@@ -48,11 +48,11 @@ Editează această pagină
 image
 imagine
 download
-
+descarcă
 CGI Internal error: %s
-
+Eroare internă CGI: %s
 Invalid action parameter %s
-
+Parametrul %s pentru acţiune nu este valid
 Invalid URL.
 URL incorect.
 Page name is missing
@@ -60,25 +60,25 @@ Lipseşte numele paginii.
 Page name is too long: %s
 Numele paginii este prea lung: %s
 Invalid Page %s (must not end with .db)
-
+Pagina %s nu este validă (nu se poate termina cu .db)
 Invalid Page %s (must not end with .lck)
-
+Pagina %s nu este validă (nu se poate termina cu .lck)
 Invalid Page %s
-
+Pagina %s nu este validă
 Preview:
 Previzualizare:
 Preview only, not yet saved
 Previzualizare, pagina nu a fost încă salvată
 Please go on to %s.
-
+Vă rugăm să continuaţi la %s.
 Could not open %s log file
-
+Fişierul cu înregistrări %s nu a putut fi deschis
 Error was
 Eroarea a fost
 Note: This error is normal if no changes have been made.
-
+Notă: Această eroare este normală dacă nu au fost făcute modificări.
 Could not open old %s log file
-
+Fişierul cu înregistrări vechi %s nu a putut fi deschis
 No updates since %s
 Nici o modificare de la %s
 Updates since %s
@@ -124,7 +124,7 @@ nou
 from %s
 de la %s
 This page is too big to send over RSS.
-
+Această pagină este prea voluminoasă pentru a putea fi trimisă prin RSS.
 History of %s
 Istorcul %s
 Compare
@@ -158,7 +158,7 @@ Deblochează site-ul
 Lock site
 Blochează site-ul
 Install CSS
-
+Instalare CSS
 Unlock %s
 Deblochează %s
 Lock %s
@@ -170,7 +170,7 @@ Acţiuni:
 Important pages:
 Pagini importante:
 To mark a page for deletion, put <strong>%s</strong> on the first line.
-
+Pentru a marca o pagină pentru a fiştearsă, puneţi <strong>%s</strong> pe primul rând.
 [Home]
 [Acasă]
 redirected from %s
@@ -212,7 +212,7 @@ Vezi revizia curentă
 View all changes
 Vezi toate modificările
 Homepage URL:
-
+Adresa paginii personale.
 s
 
 Save
@@ -246,7 +246,7 @@ minoră
 No diff available.
 Nici o diferenţă disponibilă.
 The two revisions are the same.
-
+Cele două revizii sunt identice.
 Old revision:
 Revizia veche:
 Changed:
@@ -260,25 +260,25 @@ ca
 Revision %s not available
 Revizia %s nu este disponibilă
 showing current revision instead
-
+arată revizia curentă în loc
 Showing revision %s
-
+Arată revizia %s
 Cannot save a nameless page.
-
+Nu pot salva o pagină fără nume.
 Cannot save a page without revision.
-
+Nu pot salva o pagină fără revizie.
 Cannot open %s
-
+Nu pot deschide %s
 Cannot write %s
-
+Nu pot scrie %s
 Cannot create %s
-
+Nu pot crea %s
 Could not get %s lock
 
 The lock was created %s.
 
 This operation may take several seconds...
-
+Această operaţie poate dura mai multe secunde...
 Forced unlock of %s lock.
 
 No unlock required.
@@ -332,7 +332,7 @@ Fişier pentru adăugare.
 Files of type %s are not allowed.
 Fişierele de tipul %s nu sunt permise.
 Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
-
+Parola dumneavoastră este salvată într-un cookie, dacă aveţi activat suportul cookie. Aceste cookie se pot pierde dacă vă conectaţi de la alt terminal, cu alt cont, sau alt program.
 You are currently an administrator on this site.
 Sunteţi administrator pe acest site.
 You are currently an editor on this site.
@@ -416,7 +416,7 @@ The page contains banned text.
 No changes to be saved.
 
 This page was changed by somebody else %s.
-
+Această pagină a fost modificată de altcineva %s.
 The changes conflict.  Please check the page again.
 
 Please check whether you overwrote those changes.
@@ -426,7 +426,7 @@ Anonim
 Cannot delete the index file %s.
 Nu am putut şterge fişierul index %s.
 Please check the directory permissions.
-
+Vă rog să verificaţi permisiunile directorului.
 Your changes were not saved.
 Modificările nu au fost salvate.
 Could not get a lock to merge!
@@ -542,45 +542,45 @@ Precedent
 Next
 Următor
 Calendar %s
-
+Calendar %s
 Su
-
+Du
 Mo
-
+Lu
 Tu
-
+Ma
 We
-
+Mi
 Th
-
+Jo
 Fr
-
+Vi
 Sa
-
+Sî
 January
-
+Ianuarie
 February
-
+Februarie
 March
-
+Martie
 April
-
+Aprilie
 May
-
+Mai
 June
-
+Iunie
 July
-
+Iulie
+August
 August
-
 September
-
+Septembrie
 October
-
+Octombrie
 November
-
+Noiembrie
 December
-
+Decembrie
 Clustermap
 
 Pages without a Cluster
@@ -596,11 +596,11 @@ Compilation tag is missing a regular expression.
 Despamming pages
 
 Cannot find revision %s.
-
+Revizia %s nu a putut fi găsită.
 Revert to revision %1: %2
-
+Revenire la revizia %1: %2
 Marked as %s.
-
+Marcat ca %s.
 Cannot find unspammed revision.
 
 Add Comment
@@ -642,7 +642,7 @@ Parolele nu se potrivesc.
 The password must be at least %s characters.
 Lungimea parolei trebuie să fie de cel puţin %s caractere.
 That email address is invalid.
-
+Adresa de email nu este validă.
 The username %s has already been registered.
 
 Your registration for %s has been submitted.
@@ -696,7 +696,7 @@ You are logged in as %s.
 You are not logged in.
 
 Reset Password
-
+Resetează Parola
 The password for %s was reset.  It has been emailed to the address on file.
 
 There was an error resetting the password for %s.
@@ -744,7 +744,7 @@ LocalMap
 No page id for action localmap
 
 Requested page %s does not exist
-
+Pagina %s nu există
 Local Map for %s
 
 view
@@ -800,7 +800,7 @@ Result pages:
 Slideshow:%s
 
 Static Copy
-
+Copie Statică
 Back to %s
 Înapoi la %s
 Copy to %1 succeeded: %2.
@@ -836,9 +836,9 @@ Conţinut
 This page is a translation of %s. 
 Această pagină este o traducere a %s.
 The translation is up to date.
-
+Traducerea este curentă.
 The translation is outdated.
-
+Traducerea nu este curentă.
 The page does not exist.
 Pagina nu există.
 http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s
