@@ -34,20 +34,19 @@ sub initialize {
 sub process {
   my ($self, $oldwords) = @_;
   my $string = join("\n", @$oldwords);
-  my @words = ($string =~ /[A-Za-z0-9\x80-\xff]+/g);
+  my @words = map { lc } ($string =~ /[A-Za-z0-9\x80-\xff]+/g);
   return \@words;
 };
 
 package OddMuse;
 
-$ModulesDescription .= '<p>$Id: search-freetext.pl,v 1.30 plus patches $</p>';
+$ModulesDescription .= '<p>$Id: search-freetext.pl,v 1.45 2006/06/13 19:40:29 as Exp $</p>';
 
 push(@MyRules, \&SearchFreeTextTagsRule);
 
-use vars qw($SearchFreeTextTagUrl $SearchFreeTextNewForm);
+use vars qw($SearchFreeTextTagUrl);
 
 $SearchFreeTextTagUrl = 'http://technorati.com/tag/';
-$SearchFreeTextNewForm = 1;
 
 sub SearchFreeTextTagsRule {
   if (m/\G(\[\[tag:$FreeLinkPattern\]\])/cog
@@ -75,11 +74,12 @@ sub SearchFreeTextMenu {
 $Action{buildindex} = \&SearchFreeTextIndex;
 
 sub SearchFreeTextIndex {
-  print GetHttpHeader('text/plain');
   if (not eval { require Search::FreeText;  }) {
+    print GetHttpHeader('text/plain', 'nocache', '500 INTERNAL SERVER ERROR');
     print T('Search::FreeText is not available on this system.') ."\n";
     return;
   }
+  print GetHttpHeader('text/plain');
   my $wordfile = $DataDir . '/word.db';
   my $tagfile = $DataDir . '/tags.db';
   if (!UserIsAdmin()) {
@@ -97,17 +97,21 @@ sub SearchFreeTextIndex {
   $tags->clear_index();
   foreach my $name (AllPagesList()) {
     OpenPage($name);
-    next if ($Page{text} =~ /^#FILE /); # skip files
     print $name, "\n";
     # don't forget to add the pagename to the page text, without
     # underscores
     my $page = $OpenPageName;
     $page =~ s/_/ /g;
-    $words->index_document($name, $page . ' ' . $Page{text});
+    # UrlEncode key because the internal datastructure uses commas, for example.
     my @tags = ($Page{text} =~ m/\[\[tag:$FreeLinkPattern\]\]/g,
 		$Page{text} =~ m/\[\[tag:$FreeLinkPattern\|([^]|]+)\]\]/g);
-    next unless @tags;
-    $tags->index_document($name, join(' ', @tags)); # add tags
+    # add tags, even for files
+    $tags->index_document(UrlEncode($name), join(' ', @tags)) if @tags;
+    # no word index for files
+    my $text = $page . ' ';
+    my ($type) = TextIsFile($Page{text});
+    $text .= $type ? $type : $Page{text};
+    $words->index_document(UrlEncode($name), $text);
   }
   $words->close_index();
   $tags->close_index();
@@ -126,7 +130,6 @@ sub SearchFreeTextCloud {
   my $tagfile = $DataDir . '/tags.db';
   my $tags = SearchFreeTextDB($tagfile);
   $tags->open_index();
-  # my @found = $db->search(join(" ", @wanted));
   my $db = $tags->{_Database};
   my $max = 0;
   my $min = 0;
@@ -142,7 +145,7 @@ sub SearchFreeTextCloud {
   }
   foreach (sort keys %count) {
     my $n = $count{$_};
-    print $q->a({-href  => "$ScriptName?search=tag:$_",
+    print $q->a({-href  => "$ScriptName?search=tag:" . UrlEncode($_),
 		 -title => $n,
 		 -style => 'font-size: '
 		 . int(80+120*($n-$min)/($max-$min)) . '%;',
@@ -153,36 +156,6 @@ sub SearchFreeTextCloud {
   PrintFooter();
 }
 
-# override old DoSearch
-
-*SearchFreeTextOldDoSearch = *DoSearch;
-*DoSearch = *SearchFreeTextNewDoSearch;
-
-sub SearchFreeTextNewDoSearch {
-  if (GetParam('old', 0) or (GetParam('replace', '')) or not $SearchFreeTextNewForm) {
-    SearchFreeTextOldDoSearch(@_);
-  } else {
-    local *SearchTitleAndBody = *SearchFreeTextTitleAndBody;
-    local *HighlightRegex = *SearchFreeTextNewHighlightRegex;
-    SearchFreeTextOldDoSearch(@_);
-  }
-}
-
-# override code for rcfilteronly
-
-*SearchFreeTextOldGetRc = *GetRc;
-*GetRc = *SearchFreeTextNewGetRc;
-
-sub SearchFreeTextNewGetRc {
-  if (GetParam('old', 0)) {
-    SearchFreeTextOldGetRc(@_);
-  } else {
-    local *SearchTitleAndBody = *SearchFreeTextTitleAndBody;
-    local *HighlightRegex = *SearchFreeTextNewHighlightRegex;
-    SearchFreeTextOldGetRc(@_);
-  }
-}
-
 # override the standard printing of results
 *SearchResultCount = *SearchFreeTextNop;
 
@@ -193,7 +166,11 @@ sub SearchFreeTextNop { '' };
 my $SearchFreeTextNum = 10;  # results per page
 my $SearchFreeTextMax = 10;  # max. number of pages
 
-sub SearchFreeTextTitleAndBody {
+*OldSearchFreeTextTitleAndBody = *SearchTitleAndBody;
+*SearchTitleAndBody = *NewSearchFreeTextTitleAndBody;
+
+sub NewSearchFreeTextTitleAndBody {
+  return OldSearchFreeTextTitleAndBody(@_) if GetParam('old', 0);
   my ($term, $func, @args) = @_;
   ReportError(T('Search term missing.'), '400 BAD REQUEST') unless $term;
   require Search::FreeText;
@@ -204,9 +181,9 @@ sub SearchFreeTextTitleAndBody {
   my @wanted = $term  =~ m/(".*?"|tag:".*?"|\S+)/g;
   my @wanted_words = grep(!/^tag:/, @wanted);
   my @wanted_tags = map { substr($_, 4) } grep(/^tag:/, @wanted);
-  my @words = SearchFreeTextGet(SearchFreeTextDB($DataDir . '/word.db'),
+  my @words = SearchFreeTextGet(SearchFreeTextDB($DataDir . '/word.db'), 0,
 				@wanted_words);
-  my @tags = SearchFreeTextGet(SearchFreeTextDB($DataDir . '/tags.db'),
+  my @tags = SearchFreeTextGet(SearchFreeTextDB($DataDir . '/tags.db'), 1,
 			       @wanted_tags);
   my @result = ();
   if (not @wanted_words and not @wanted_tags) {
@@ -226,7 +203,11 @@ sub SearchFreeTextTitleAndBody {
   # limit to the result page requested
   $max = @result - 1 if @result -1 < $max;
   my $count = ($page - 1) * $limit;
-  my @items = @result[($page - 1) * $limit  .. $max];
+  my @items = @result;
+  @items = @items[($page - 1) * $limit  .. $max]
+    unless $CollectingJournal                      # no limit when building a journal,
+      or GetParam('action', 'browse') eq 'rc'      # filtering recent changes or the
+      or GetParam('action', 'browse') eq 'rss';    # rss feed.
   # print links, if this is is really a search
   my $raw = GetParam('raw','');
   my @links = ();
@@ -250,7 +231,7 @@ sub SearchFreeTextTitleAndBody {
     unshift(@links, ScriptLink($prev, T('Previous'))) if $prev;
     push(@links, ScriptLink($next, T('Next'))) if $next;
     print $q->p({-class=>'top pages'}, T('Result pages: '), @links,
-		Ts("(%s results)", $#result + 1)) unless $raw;
+		Ts("(%s results)", $#result + 1)) if $func and not $raw;
   }
   # print result
   foreach my $id (@items) {
@@ -259,29 +240,35 @@ sub SearchFreeTextTitleAndBody {
   # repeat result pages at the bottom
   if (GetParam('search', '') and @items) {
     print $q->p({-class=>'bottom pages'}, T('Result pages: '), @links,
-		Ts("(%s results)", $#result + 1)) unless $raw;
+		Ts("(%s results)", $#result + 1)) if $func and not $raw;
   }
   return @items;
 }
 
 sub SearchFreeTextGet {
-  my ($db, @wanted) = @_;
+  my ($db, $tags, @wanted) = @_;
   return unless @wanted; # shortcut
   my @result = ();
   # open file and get sorted list of arrays with page id and rank.
   $db->open_index();
   my @found = $db->search(join(" ", @wanted));
   $db->close_index();
-  # make sure that all double quoted phrases do in fact all appear.
-  # to do this, we copy page ids from @found.
-  my @phrases = map { quotemeta(substr($_,1,-1)) } grep(/^"/, @wanted);
+  # Make sure that all double quoted phrases do in fact all appear. To
+  # do this, we copy page ids from @found. Quote potential regular
+  # expressions in search strings. Backlink searches are already
+  # quoted, however -- thus only do it if no backslash is found.
+  my @phrases = map { $_ = substr($_,1,-1); $_ = QuoteRegexp($_) unless index('\\', $_); $_; } grep(/^"/, @wanted);
+  @phrases = map { "\\[\\[tag:$_\\]\\]" } @phrases if $tags;
  PAGE: foreach (@found) {
-    my ($id, $score) = ($_->[0], $_->[1]);
+    my ($id, $score) = (UrlDecode($_->[0]), $_->[1]);
     if (@phrases) {
       OpenPage($id);
+      my $text = $OpenPageName;
+      $text =~ s/_/ /g;
+      $text .= "\n" . $Page{text};
       foreach my $phrase (@phrases) {
 	# don't add it to @found by skipping to the next page
-	next PAGE unless $Page{text} =~ m/$phrase/;
+	next PAGE unless $text =~ m/$phrase/;
       }
     }
     push(@result, $id); # order is important, so no hashes
@@ -308,8 +295,55 @@ sub SearchFreeTextDB {
 
 # highlighting changes if new search is used
 
-sub SearchFreeTextNewHighlightRegex {
+*OldSearchFreeTextNewHighlightRegex = *HighlightRegex;
+*HighlightRegex = *NewSearchFreeTextNewHighlightRegex;
+
+sub NewSearchFreeTextNewHighlightRegex {
+  return OldSearchFreeTextNewHighlightRegex(@_) if GetParam('old', 0);
   $_ = shift;
   s/\"//g;
   return join('|', split);
 }
+
+# tagging of uploaded files
+
+*OldSearchFreePrintFooter = *PrintFooter;
+*PrintFooter = *NewSearchFreePrintFooter;
+
+sub NewSearchFreePrintFooter {
+  my ($id, $rev, $comment) = @_;
+  if (defined &SearchFreeTextTagsRule and TextIsFile($Page{text})) {
+    my @tags = $Page{text} =~ /\[\[tag:$FreeLinkPattern\]\]/g;
+    if ($rev eq 'edit') {
+      print $q->div({-class=>'edit tags'}, GetFormStart(),
+		    $q->p(GetHiddenValue('id', $id), GetHiddenValue('action', 'retag'),
+			  T('Tags:'), $q->br(), GetTextArea('tags', join(' ', @tags), 2),
+			  $q->br(), $q->submit(-name=>'Save', -value=>T('Save'))),
+		    $q->endform());
+    } elsif ($id and @tags) {
+      print $q->div({-class=>'tags'},
+		    $q->p(T('Tags: '), map { $_ = "\[\[tag:$_\]\]";
+					     SearchFreeTextTagsRule(); } @tags));
+    }
+  }
+  OldSearchFreePrintFooter(@_);
+}
+
+$Action{retag} = \&SearchFreeDoTag;
+
+sub SearchFreeDoTag {
+  my $id = shift;
+  my $name = $id;
+  $name =~ s/_/ /g;
+  my $tags = GetParam('tags', '');
+  my $summary = Ts('Tags: %s.', $tags) || T('No tags');
+  $tags = join(' ', map { "\[\[tag:$_\]\]" } split(' ', $tags));
+  OpenPage($id);
+  my $text = $Page{text};
+  $text =~ s/\[\[tag:$FreeLinkPattern\]\]\s*//g; # remove all existing tags
+  $text =~ s/\n\nTags: /\n\nTags: $tags/ or $text .= "\n\nTags: $tags" if $tags;
+  RequestLockOrError(); # fatal
+  Save($id, $text, $summary, 1, 1); # treat as upload: no diffs and no language
+  ReleaseLock();
+  ReBrowsePage($id);
+}
