@@ -17,7 +17,7 @@
 #
 # This translation was last checked for Oddmuse version 1.195.
 #
-$ModulesDescription .= '<p>$Id: spanish-utf8.pl,v 1.6 2005/10/09 12:48:35 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: spanish-utf8.pl,v 1.8 2006/05/10 22:52:16 as Exp $</p>';
 %Translate = split(/\n/,<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 Consulta no permitida: el usuario, ip o sub-red ha sido bloqueado.
@@ -29,6 +29,8 @@ UserName must be 50 characters or less: not saved
 UserName debe tener un tamaño de 50 caracteres o menos: no ha sido guardado.
 This page contains an uploaded file:
 
+Recursive include of %s!
+
 XML::RSS is not available on this system.
 
 diff
@@ -59,14 +61,12 @@ Page name is missing
 
 Page name is too long: %s
 El nombre de la página es demasiado largo: %s
-Invalid Page %s
-Página %s Inválida
 Invalid Page %s (must not end with .db)
 Página %s Inválida (no debe terminar con la extensión .db)
 Invalid Page %s (must not end with .lck)
 Página %s Inválida (no debe terminar con la extensión .lck)
-Page name may not contain space characters: %s
-El nombre de la página no puede contener caracteres de espacio: %s
+Invalid Page %s
+Página %s Inválida
 Preview:
 Previsualización:
 Preview only, not yet saved
@@ -219,6 +219,8 @@ s
 
 Save
 Guardar
+p
+
 Preview
 Previsualización
 Search:
@@ -275,6 +277,8 @@ Cannot create %s
 
 Could not get %s lock
 
+The lock was created %s.
+
 This operation may take several seconds...
 Esta operación puede tomar varios segundos...
 Forced unlock of %s lock.
@@ -467,8 +471,6 @@ Edit lock removed.
 Se ha eliminado el bloqueo de edición.
 Set or Remove page edit lock
 Establecer o Remover el bloqueo de edición de una página
-Missing page id to lock/unlock...
-No se ha encontrado ID de la página a bloquear/desbloquear...
 Lock for %s created.
 Se ha creado bloqueo para %s.
 Lock for %s removed.
@@ -519,6 +521,8 @@ Immediately delete %s
 
 Rename %s to:
 
+Learn more...
+
 Cannot highlight the language %s.
 
 Recent Visitors
@@ -529,7 +533,7 @@ was here
 
 and read
 
-Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
+Illegal year value: Use 0001-9999
 
 The match parameter is missing.
 
@@ -541,6 +545,44 @@ Next
 
 Calendar %s
 
+Su
+
+Mo
+
+Tu
+
+We
+
+Th
+
+Fr
+
+Sa
+
+January
+
+February
+
+March
+
+April
+
+May
+
+June
+
+July
+
+August
+
+September
+
+October
+
+November
+
+December
+
 Clustermap
 
 Pages without a Cluster
@@ -571,11 +613,9 @@ Footnotes:
 
 Could not find %1.html template in %2
 
-Only Editors are allowed to see hidden pages.
+Only Editors are allowed to see this hidden page.
 
-Only Admins are allowed to see hidden pages.
-
-image: %s
+Only Admins are allowed to see this hidden page.
 
 Index
 
@@ -591,6 +631,10 @@ Template without parameters
 
 The template %s is either empty or does not exist.
 
+ -- defined on %s
+
+Local names defined on %1: %2
+
 Register for %s
 
 Please choose a username of the form "FirstLast" using your real name.
@@ -605,9 +649,9 @@ The username %s has already been registered.
 
 Your registration for %s has been submitted.
 
-  Please allow time for the webmaster to approve your request.
+Please allow time for the webmaster to approve your request.
 
-  An email has been sent to "%s" with further instructions.
+An email has been sent to "%s" with further instructions.
 
 There was an error saving your registration.
 
@@ -621,7 +665,7 @@ Logged in as %s.
 
 Logout of %s
 
-<p>Logout of %s?</p>
+Logout of %s?
 
 Logged out of %s
 
@@ -657,17 +701,17 @@ Reset Password
 
 The password for %s was reset.  It has been emailed to the address on file.
 
-There was an error resetting the password for %s
+There was an error resetting the password for %s.
 
 The username "%s" does not exist.
 
 Reset Password for %s
 
-<p>Reset Password?</p>
+Reset Password?
 
 Change Password for %s
 
-<p>Change Password?</p>
+Change Password?
 
 Your current password is incorrect.
 
@@ -687,6 +731,8 @@ There was an error approving %s.
 
 There are no pending registrations.
 
+%s is not a legal name for a namespace
+
 Clearing Cache
 
 Done.
@@ -719,6 +765,12 @@ Type
 
 Permalink to "%s"
 
+There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.
+
+Someone else is generating a pdf for %s.  Please wait a minute and then try again.
+
+Download this page as PDF
+
 Portrait
 
 You did not answer correctly.
@@ -727,9 +779,11 @@ All Referrers
 Todos los orígenes
 Referrers
 Orígenes
+Tag
+
 Rebuild index for searching
 
-Rebuilding Index
+Tag Cloud
 
 Search::FreeText is not available on this system.
 
@@ -737,6 +791,8 @@ Rebuilding index not done.
 
 (Rebuilding the index can only be done once every 12 hours.)
 
+ ... 
+
 Search term missing.
 
 Result pages: 
@@ -753,8 +809,6 @@ Copy to %1 succeeded: %2.
 
 Copy to %1 failed: %2.
 
-Tag
-
 Alternatively, use one of the following templates:
 
 Thread: %s
